/**
 * Copyright 2024 SCOOP Software GmbH, cronn GmbH
 * SPDX-License-Identifier: AGPL-3.0-only
 */

import { ApiAddFacilityFileStateRequestContactAddress } from "@eshg/employee-portal-api/base";
import { Grid } from "@mui/joy";
import { isDefined, isNonNullish } from "remeda";

import { BaseAddressDetails } from "@/lib/shared/components/address/BaseAddressDetails";
import { InfoTile } from "@/lib/shared/components/infoTile/InfoTile";
import { InfoTileAddButton } from "@/lib/shared/components/infoTile/InfoTileAddButton";

export interface BillingAddressTileProps {
  billingAddress?: ApiAddFacilityFileStateRequestContactAddress;
  readonly?: boolean;
  setOpen: (initialState: boolean) => void;
}

export function BillingAddressTile({
  billingAddress,
  readonly,
  setOpen,
}: Readonly<BillingAddressTileProps>) {
  function handleEdit() {
    setOpen(true);
  }

  function handleAddButton() {
    setOpen(true);
  }

  return (
    <InfoTile
      name="billingAddress"
      title="Abweichende Rechnungsadresse"
      onEdit={
        isNonNullish(billingAddress) && !readonly ? handleEdit : undefined
      }
    >
      <Grid container direction="column" sx={{ gap: 2 }}>
        {!isNonNullish(billingAddress) && (
          <InfoTileAddButton onClick={handleAddButton}>
            Hinzufügen
          </InfoTileAddButton>
        )}
        {isDefined(billingAddress) && (
          <BaseAddressDetails address={billingAddress} />
        )}
      </Grid>
    </InfoTile>
  );
}
