/**
 * Copyright 2024 SCOOP Software GmbH, cronn GmbH
 * SPDX-License-Identifier: AGPL-3.0-only
 */

"use client";

import { useSuspenseQueries } from "@tanstack/react-query";

import {
  useObjectTypeApi,
  usePacklistDefinitionApi,
} from "@/lib/businessModules/inspection/api/clients";
import { getObjectTypesQuery } from "@/lib/businessModules/inspection/api/queries/objectTypes";
import { getPacklistDefinitionRevisionQuery } from "@/lib/businessModules/inspection/api/queries/packlistDefinition";
import { CreateOrEditPacklistDefinitionSidebar } from "@/lib/businessModules/inspection/components/packlistDefinition/CreateOrEditPacklistDefinitionSidebar";

interface EditPacklistDefinitionSidebarProps {
  onClose: () => void;
  readonly?: boolean;
  revisionId: string;
  version: number;
  onClickNewRevision?: (
    defId: string,
    version: number,
    revisionId: string,
  ) => void;
}

export function EditPacklistDefinitionSidebar({
  onClose,
  readonly,
  revisionId,
  version,
  onClickNewRevision,
}: Readonly<EditPacklistDefinitionSidebarProps>) {
  const objectTypeApi = useObjectTypeApi();
  const packlistDefinitionApi = usePacklistDefinitionApi();

  const [{ data: packlistRevision }, { data: objectTypes }] =
    useSuspenseQueries({
      queries: [
        getPacklistDefinitionRevisionQuery(packlistDefinitionApi, revisionId),
        getObjectTypesQuery(objectTypeApi),
      ],
    });

  return (
    <CreateOrEditPacklistDefinitionSidebar
      open
      onClose={onClose}
      pldRevision={packlistRevision}
      readonly={readonly}
      title={
        readonly
          ? `Packlistendefinition ansehen: ${packlistRevision.name}`
          : `Packlistendefinition bearbeiten: ${packlistRevision.name}`
      }
      onClickNewRevision={onClickNewRevision}
      version={version}
      objectTypes={objectTypes}
    />
  );
}
